@@ -8,11 +8,6 @@ from geopy.geocoders import Nominatim
 from datetime import timedelta
 
 
-
-json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
-json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
-
-
 def earthquake_distance(place):    
 
 
@@ -37,7 +32,11 @@ def earthquake_distance(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
+
+    
     
 
     json_url = urlopen('https://earthquake.usgs.gov/fdsnws/event/1/query?format=geojson&starttime='+ str(today) +'&endtime=' + str(yesterday))
@@ -123,6 +122,8 @@ def earthquake_longitude(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
 
 
@@ -209,6 +210,8 @@ def earthquake_latitude(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
     
 
@@ -295,6 +298,8 @@ def earthquake_magnitude(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
     
 
@@ -380,6 +385,8 @@ def earthquake_place(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
     
 
@@ -466,6 +473,8 @@ def earthquake_time(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
     
 
@@ -550,6 +559,8 @@ def earthquake_df(place):
 
     today = datetime.datetime.today()
     yesterday = today - timedelta(days=1)
+    today = today.strftime('%Y-%m-%d')
+    yesterday = yesterday.strftime('%Y-%m-%d')
 
     
 
